@@ -32,7 +32,7 @@
 //! pub const COMMIT_AUTHOR :&str = "baoyachi";
 //! pub const BUILD_TIME :&str = "2020-08-16 13:48:52";
 //! pub const BUILD_TIME_2822 :&str = "Thu, 24 Jun 2021 21:44:14 +0800";
-//! pub const BUILD_TIME_3339 :&str = "2021-06-24T21:44:14.473058+08:00";
+//! pub const BUILD_TIME_3339 :&str = "2021-06-24T15:53:55+08:00";
 //! pub const COMMIT_DATE :&str = "2020-08-16 13:12:52";
 //! pub const COMMIT_DATE_2822 :&str = "Thu, 24 Jun 2021 21:44:14 +0800";
 //! pub const COMMIT_DATE_3339 :&str = "2021-06-24T21:44:14.473058+08:00";
@@ -60,6 +60,8 @@
 //! pub const CARGO_VERSION :&str = "cargo 1.45.0 (744bd1fbb 2020-06-15)";
 //! pub const BUILD_OS :&str = "macos-x86_64";
 //! pub const COMMIT_HASH :&str = "386741540d73c194a3028b96b92fdeb53ca2788a";
+//! pub const GIT_CLEAN :bool = true;
+//! pub const GIT_STATUS_FILE :&str = "* src/lib.rs (dirty)";
 //! ```
 //! # Setup Guide
 //!
@@ -71,10 +73,10 @@
 //! build = "build.rs"
 //!
 //! [dependencies]
-//! shadow-rs = "0.5"
+//! shadow-rs = "0.6"
 //!
 //! [build-dependencies]
-//! shadow-rs = "0.5"
+//! shadow-rs = "0.6"
 //! ```
 //!
 //! ### 2) Create `build.rs` file
@@ -123,6 +125,8 @@
 //!    println!("{}",build::PROJECT_NAME);//shadow-rs
 //!    println!("{}",build::BUILD_TIME);//2020-08-16 14:50:25
 //!    println!("{}",build::BUILD_RUST_CHANNEL);//debug
+//!    println!("{}",build::GIT_CLEAN);//false
+//!    println!("{}",build::GIT_STATUS_FILE);//* src/lib.rs (dirty)
 //! }
 //!```
 //!
@@ -304,7 +308,7 @@ impl Shadow {
         let ci_type = shadow.try_ci();
         let src_path = Path::new(src_path.as_str());
 
-        let mut map = new_git(&src_path, ci_type, &shadow.std_env);
+        let mut map = new_git(src_path, ci_type, &shadow.std_env);
         for (k, v) in new_project(&shadow.std_env) {
             map.insert(k, v);
         }
@@ -333,6 +337,7 @@ impl Shadow {
 
     fn gen_const(&mut self) -> SdResult<()> {
         for (k, v) in self.map.clone() {
+            println!("k:{},v:{:?}", k, v);
             self.write_const(k, v)?;
         }
         Ok(())
@@ -353,18 +358,30 @@ impl Shadow {
     fn write_const(&mut self, shadow_const: ShadowConst, val: ConstVal) -> SdResult<()> {
         let desc = format!("/// {}", val.desc);
 
-        let (t, v) = match val.t {
-            ConstType::OptStr => (ConstType::Str.to_string(), "".into()),
-            ConstType::Str => (ConstType::Str.to_string(), val.v),
+        let define = match val.t {
+            ConstType::OptStr => format!(
+                "#[allow(dead_code)]\n\
+            pub const {} :{} = r#\"{}\"#;",
+                shadow_const.to_ascii_uppercase(),
+                ConstType::Str.to_string(),
+                ""
+            ),
+            ConstType::Str => format!(
+                "#[allow(dead_code)]\n\
+            pub const {} :{} = r#\"{}\"#;",
+                shadow_const.to_ascii_uppercase(),
+                ConstType::Str.to_string(),
+                val.v
+            ),
+            ConstType::Bool => format!(
+                "#[allow(dead_code)]\n\
+            pub const {} :{} = {};",
+                shadow_const.to_ascii_uppercase(),
+                ConstType::Bool.to_string(),
+                val.v.parse::<bool>().unwrap()
+            ),
         };
 
-        let define = format!(
-            "#[allow(dead_code)]\n\
-            pub const {} :{} = r#\"{}\"#;",
-            shadow_const.to_ascii_uppercase(),
-            t,
-            v
-        );
         writeln!(&self.f, "{}", desc)?;
         writeln!(&self.f, "{}\n", define)?;
         Ok(())
